Configure
=========

Documentation is in development.

Currently you can use demo app code as an example for v2: https://github.com/pulse-mind/django-suit/blob/v2/demo/demo/apps.py

v2 demo app code: https://github.com/pulse-mind/django-suit/tree/v2/demo
